GADSdat Objects are (Nearly) EqualRun tests to check whether two GADSdat objects are (nearly) equal. Variable names, number of rows in the data,
meta data and data differences are checked and reported as a list output.
equalGADS(
target,
current,
metaExceptions = c("display_width", "labeled"),
tolerance = sqrt(.Machine$double.eps)
)Returns a list.
A GADSdat object.
A GADSdat object.
Should certain meta data columns be excluded from the comparison?
A numeric value greater than or equal to 0. Differences smaller than tolerance are not reported.
The default value is close to 1.5e-8.