powered by
GADSdat
Reorder a single variables in a GADSdat. The variable (var) can be inserted right after another variable (varBefore).
var
varBefore
insertVariable(GADSdat, var, varBefore)
Returns a GADSdat object.
A GADSdat object.
Character string of the variable name which should be sorted.
Character string of the variable name which should be followed by var.
The variables in the dat and in the labels section are ordered. For reordering the whole GADSdat, see orderLike.
dat
labels
orderLike
pisa2 <- insertVariable(pisa, var = "migration", varBefore = "idclass")
Run the code above in your browser using DataLab