Learn R Programming

eatGADS (version 1.0.0)

inspectMetaDifferences: Inspect differences in a variable.

Description

Inspect differences between two GADSdat objects in a specific variable.

Usage

inspectMetaDifferences(varName, GADSdat1, GADSdat2)

Value

A list.

Arguments

varName

A character vector of length 1 containing the variable name.

GADSdat1

A GADSdat object.

GADSdat2

A GADSdat object.

Details

Two GADSdat objects can be compared using equalGADS. If differences in the meta data are indicated for specific variables, these variables can be further inspected using inspectMetaDifferences.

Examples

Run this code
# create a second GADS with different meta data
pisa2 <- pisa
pisa2 <- changeVarLabels(pisa2, varName = "sameteach", varLabel = "Same math teacher")
pisa2 <- recodeGADS(pisa2, varName = "sameteach", oldValues = c(1, 2), newValues = c(0, 1))

# inspect via equalGADS()
equalGADS(pisa, pisa2)

# inspect via inspectMetaDifferences()
inspectMetaDifferences("sameteach", GADSdat1 = pisa, GADSdat2 = pisa2)

Run the code above in your browser using DataLab